@@ -1,29 +1,18 @@
 /*
- *  Copyright 2013  Sebastian Gottfried <sebastiangottfried@web.de>
+ *  SPDX-FileCopyrightText: 2013 Sebastian Gottfried <sebastiangottfried@web.de>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "lessonpainter.h"
 
-#include <qmath.h>
 #include <QAbstractTextDocumentLayout>
 #include <QPainter>
+#include <QTextBlock>
 #include <QTextCharFormat>
 #include <QTextCursor>
 #include <QTextDocument>
-#include <QTextFrame>
+#include <qmath.h>
 
 #include "core/lesson.h"
 #include "declarativeitems/traininglinecore.h"
@@ -71,7 +60,7 @@ LessonPainter::LessonPainter(QQuickItem* parent) :
     m_maximumWidth(0),
     m_maximumHeight(-1),
     m_imageCacheDirty(false),
-    m_trainingLineCore(0),
+    m_trainingLineCore(nullptr),
     m_currentLine(0)
 {
     this->setFlag(QQuickPaintedItem::ItemHasContents, true);
